<?php
/*	Modul: alkisfsnw.php

	ALKIS-Buchauskunft, Kommunales Rechenzentrum Minden-Ravensberg/Lippe (Lemgo).
	Flurstücksnachweis fuer ein Flurstückskennzeichen aus ALKIS PostNAS

	Version:
	2016-02-24 Version fuer norGIS-ALKIS-Import
	2016-03-14 Korrekturen
	2016-12-01 HTML5, Gemeinsam genutzte Datenbanken ermöglichen
	2016-12-05 Nutzungsart-Kategorie ist nun in Text enthalten, nicht mehr aus der Definition ausschneiden
	2017-06-08 optional "berechtigte Buchungen" anzeigen, Function "eigentuemer" ohne Parameter $con,
				Validierung Eingabeparameter, Feinkorrekturen
	2017-10-11 Sauber filtern auf 'endet IS NULL', Ausgabe der Bodenschätzung
	2017-10-11 Nachbesserung Formatierung der Schätzungs-Zeilen
	2017-10-17 Zeitpunkt der Entstehung in deutschen Datumsformat

	ToDo:
	- Parameter zum Umschalten mit/ohne Bodenschätzung?
	- Bessere Differenzierung bei den Nutzungsarten (Tabelle dafür aufbauen) 
*/
session_start();

// Var. aus Parameter initalisieren
$eig="n";
$berbu="n";
$showkey="n";

// alle Parameter in Variable umwandeln
$cntget = extract($_GET);

// strikte Validierung aller Parameter
if (isset($gmlid)) {
	if (!preg_match('#^[0-9A-Za-z]{16}$#', $gmlid)) {die("Eingabefehler gmlid");}
	$fskennz='';
} else { // Alternativ
	$gmlid='';
	if (isset($fskennz)) { // llgggg-fff-11111/222 oder z.B.'052647002001910013__' oder '05264700200012______'
		if (!preg_match('#^[0-9\-_/]{8,20}$#', $fskennz)) {die ("Eingabefehler fskennz");}
	} else {
		$fskennz='';
	}
}
if (!isset($gkz) or !preg_match('#^[0-9]{3}$#', $gkz)) {die("Eingabefehler gkz");}
if (!preg_match('#^[j|n]{0,1}$#', $eig)) {die("Eingabefehler eig");}
if (!preg_match('#^[j|n]{0,1}$#', $berbu)) {die ("Eingabefehler berbu");}
if (!preg_match('#^[j|n]{0,1}$#', $showkey)) {die ("Eingabefehler showkey");}
if ($showkey == "j") {$showkey=true;} else {$showkey=false;} // "j"/"n" als boolean umwandeln, ist praktischer abzufragen, wird oft gebraucht

require_once("alkis_conf_location.php");
if ($auth == "mapbender") {require_once($mapbender);}
include("alkisfkt.php");
?>
<!doctype html>
<html lang="de">
<head>
	<meta charset="utf-8">
	<meta name="viewport" content="width=device-width, initial-scale=1.0">
	<title>ALKIS Flurst&uuml;cksnachweis</title>
	<link rel="stylesheet" type="text/css" href="alkisauszug.css">
	<link rel="shortcut icon" type="image/x-icon" href="ico/Flurstueck.ico">
	<script type="text/javascript">
		function ALKISexport() {
			window.open(<?php echo "'alkisexport.php?gkz=".$gkz."&tabtyp=flurstueck&gmlid=".$gmlid."'"; ?>);
		}
	</script>
</head>
<body>
<?php
// S t a r t
$con = pg_connect($dbconn." options='--application_name=ALKIS-Auskunft_alkisfsnw.php'");
if (!$con) echo "\n<p class='err'>Fehler beim Verbinden der DB</p>";

// Ein (ALB- ?) Flurstücks-Kennzeichen wurde alternativ zur gml_id übermittelt
if ($fskennz != '') {
	// Übergabe Format z.B. "llgggg-fff-nnnn/zz.nn" oder "gggg-ff-nnn/zz"
	$arr=explode("-", $fskennz, 4);
	$zgemkg=trim($arr[0]);
	if (strlen($zgemkg) == 20 and !isset($arr[1])) { // Oh, ist wohl schon das Datenbank-Feldformat 
		$fskzdb=$zgemkg;
	} else { // Nö, ist wohl eher ALB-Format
		// Das Kennzeichen auseinander nehmen. 
		if (strlen($zgemkg) == 6) {
			$land=substr($zgemkg, 0, 2);
			$zgemkg=substr($zgemkg, 2, 4);
		} else { // kein schöner Land ..
			$land=$defland; // Default-Land aus config
		}
		$zflur=str_pad($arr[1], 3 , "0", STR_PAD_LEFT); // Flur-Nr
		$zfsnr=trim($arr[2]); // Flurstücke-Nr
		$zn=explode("/", $zfsnr, 2); // Bruch?
		$zzaehler=str_pad(trim($zn[0]), 5 , "0", STR_PAD_LEFT);
		if (isset($zn[1])) {
			$znenner=trim($zn[1]);
		} else {
			$znenner="";
		}
		if (trim($znenner, " 0.") == "") { // kein Bruch oder nur Nullen
			$znenner="____"; // in DB-Spalte mit Tiefstrich aufgefüllt
		} else {
			$zn=explode(".", $znenner, 2); // .00 wegwerfen
			$znenner=str_pad($zn[0], 4 , "0", STR_PAD_LEFT);
		}
		// nun die Teile stellengerecht wieder zusammen setzen		
		$fskzdb=$land.$zgemkg.$zflur.$zzaehler.$znenner.'__'; // FS-Kennz. Format Datenbank
	}
	// Spalte "flurstueckskennzeichen" ist in DB indiziert
	// Format z.B.'052647002001910013__' oder '05264700200012______'
	$sql ="SELECT gml_id FROM ax_flurstueck WHERE flurstueckskennzeichen= $1 AND endet IS NULL ;";

	$v = array($fskzdb);
	$res = pg_prepare("", $sql);
	$res = pg_execute("", $v);
	if ($row = pg_fetch_array($res)) {
		$gmlid=$row["gml_id"];
	} else {
		echo "\n<p class='err'>Fehler! Kein Treffer f&uuml;r Flurst&uuml;ckskennzeichen='".$fskennz."' (".$fskzdb.")</p>";
		echo "<p>Kennzeichen veraltet? <a href='./alkisfshist.php?gkz=".$gkz."&fskennz=".$fskennz."'>Suche in der Flurst&uuml;cks-Historie</a></p>";
		echo "\n</body>\n</html>";
		return;
	}
	pg_free_result($res);
}

// F L U R S T U E C K
$sql ="SELECT f.name, f.flurnummer, f.zaehler, f.nenner, f.regierungsbezirk, f.kreis, f.gemeinde, f.amtlicheflaeche, st_area(f.wkb_geometry) AS fsgeomflae, 
to_char(cast(f.zeitpunktderentstehung AS date),'DD.MM.YYYY') AS zeitpunktderentstehung, g.gemarkungsnummer, g.bezeichnung 
FROM ax_flurstueck f LEFT JOIN ax_gemarkung g ON f.land=g.land AND f.gemarkungsnummer=g.gemarkungsnummer 
WHERE f.gml_id= $1 AND f.endet IS NULL AND g.endet IS NULL;";

$v = array($gmlid); // mit gml_id suchen
$res = pg_prepare("", $sql);
$res = pg_execute("", $v);

if (!$res) {
	echo "\n<p class='err'>Fehler bei Flurstuecksdaten</p>";
	if ($debug > 2) {echo "\n<p class='dbg'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."<br>$1 = gml_id = '".$gmlid."'</p>";}
}
if ($row = pg_fetch_array($res)) {
	$gemkname=htmlentities($row["bezeichnung"], ENT_QUOTES, "UTF-8");
	$gmkgnr=$row["gemarkungsnummer"];
	$bezirk=$row["regierungsbezirk"];
	$kreis=$row["kreis"];
	$gemeinde=$row["gemeinde"];
	$flurnummer=$row["flurnummer"];
	$zaehler=$row["zaehler"];
	$nenner=$row["nenner"];
	$flstnummer=$zaehler;
	if ($nenner > 0) {$flstnummer.="/".$nenner;} // BruchNr
	$fsbuchflae=$row["amtlicheflaeche"]; // amtliche Fl. aus DB-Feld
	$fsgeomflae=$row["fsgeomflae"]; // aus Geometrie ermittelte Fläche
	$the_Xfactor = $fsbuchflae / $fsgeomflae; // Multiplikator zur Umrechnung geometrische Abschnittsflächen in Buchfläche
	$fsbuchflaed=number_format($fsbuchflae,0,",",".") . " m&#178;"; // Display-Format dazu
	$fsgeomflaed=number_format($fsgeomflae,0,",",".") . " m&#178;";
	$entsteh=$row["zeitpunktderentstehung"];
	$name=$row["name"]; // Fortfuehrungsnummer(n)
	$arrn = explode(",", trim($name, "{}") ); // PHP-Array
} else {
	echo "\n<p class='err'>Fehler! Kein Treffer f&uuml;r Flurst&uuml;ck mit gml_id=".$gmlid."</p>";
	if ($debug > 2) {echo "\n<p class='dbg'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."<br>$1 = gml_id = '".$gmlid."'</p>";}
	echo "\n</body>\n</html>";
	return;
}
pg_free_result($res);

// Balken
if ($eig=="j") {
	echo "<p class='fsei'>ALKIS Flurst&uuml;ck ".$gmkgnr."-".$flurnummer."-".$flstnummer."&nbsp;</p>"
	."\n<h2><img src='ico/Flurstueck.png' width='16' height='16' alt=''> Flurst&uuml;ck mit Eigent&uuml;mer</h2>";
} else {
	echo "<p class='fskennz'>ALKIS Flurst&uuml;ck ".$gmkgnr."-".$flurnummer."-".$flstnummer."&nbsp;</p>"
	."\n<h2><img src='ico/Flurstueck.png' width='16' height='16' alt=''> Flurst&uuml;ck</h2>";
}

// Prüfung der Gebiets-Berechtigung bei gemeinsam genutzten Datenbanken (Kreis und Gemeinde)
// Für das gkz (z.B. aus dem Mapfile-Namen) wird in der Konfiguration ein Filter gesetzt.
if ( ($filtkreis != '' and $filtkreis != $kreis) or ($filtgem != '' and $filtgem != $gemeinde) ) {
	// Einer der gesetzten Filter passt nicht
	if ($debug > 2) {
	//++ Schönes Bild? Stop-Zeichen?
		echo "\n<p class='err'>Filter Kreis='".$filtkreis."', Gemeinde='".$filtgem."'</p>"
		."\n<p class='err'>Flstk. Kreis='".$fskrs."', Gemeinde='".$fsgem."'</p>";
	}
	echo "\n<br><p class='stop1'>Zugriff nicht erlaubt</p>"
	."\n<br><p class='stop2'>Dies Flurst&uuml;ck liegt ausserhalb der zust&auml;ndigen Stadt oder Gemeinde.</p>\n</body>\n</html>";
	exit;
}

echo "\n<table class='outer'>\n<tr>\n\t<td>" // linke Seite
	."\n\t\t<table class='kennzfs' title='Flurst&uuml;ckskennzeichen'>\n\t\t<tr>" // darin Tabelle Kennzeichen
		."\n\t\t\t<td class='head'>Gmkg</td>\n\t\t\t<td class='head'>Flur</td>\n\t\t\t<td class='head'>Flurst-Nr.</td>\n\t\t</tr>"
		."\n\t\t<tr>\n\t\t\t<td title='Gemarkung'>";
		if ($showkey) {
			echo "<span class='key'>".$gmkgnr."</span><br>";
		}
		echo $gemkname."&nbsp;</td>"
		."\n\t\t\t<td title='Flurnummer'>".$flurnummer."</td>"
		."\n\t\t\t<td title='Flurst&uuml;cksnummer (Z&auml;hler / Nenner)'><span class='wichtig'>".$flstnummer."</span></td>\n\t\t</tr>"
	."\n\t\t</table>"
."\n\t</td>\n\t<td>" // rechte Seite
	."\n\t\t<table class='fsd'>" // FS-Daten 2 Spalten
		."\n\t\t<tr>\n\t\t\t<td>Entstehung</td>"
		."\n\t\t\t<td>".$entsteh."</td>\n\t\t</tr>"
		."\n\t\t<tr>"
			."\n\t\t\t<td>letz. Fortf</td>"
			."\n\t\t\t<td title='Jahrgang / Fortf&uuml;hrungsnummer - Fortf&uuml;hrungsart'>";
				foreach($arrn AS $val) { // Zeile f. jedes Element des Array
					echo trim($val, '"')."<br>";
				}
			echo "</td>"
		."\n\t\t</tr>"
	."\n\t\t</table>"
."\n\t</td>\n</tr>\n</table>";
//	echo "\n<tr>\n\t<td>Finanzamt</td>\n\t<td>".$finanzamt." ".$finame  . "</td>\n</tr>";
// Ende Seitenkopf

echo "\n<hr>"
."\n<p class='nwlink noprint'>weitere Auskunft:</p>" // oben rechts von der Tabelle
."\n<table class='fs'>";

// ** G e b i e t s z u g e h o e r i g k e i t **
// eine Tabellenzeile mit der Gebietszugehoerigkeit eines Flurstuecks wird ausgegeben
// Schluessel "land" wird nicht verwendet, gibt es Bestaende wo das nicht einheitlich ist?
echo "\n<tr>\n\t<td class='ll'><img title='Im Gebiet von' src='ico/Gemeinde.png' width='16' height='16' alt=''> Gebiet:</td>";

// G e m e i n d e
$sql="SELECT bezeichnung FROM ax_gemeinde WHERE regierungsbezirk= $1 AND kreis= $2 AND gemeinde= $3 AND endet IS NULL;"; 

$v = array($bezirk,$kreis,$gemeinde);
$res = pg_prepare("", $sql);
$res = pg_execute("", $v);
if (!$res) {
	echo "\n<p class='err'>Fehler bei Gemeinde</p>";
	if ($debug > 2) {echo "\n<p class='dbg'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."</p>";}
}
$row = pg_fetch_array($res);
$gnam = htmlentities($row["bezeichnung"], ENT_QUOTES, "UTF-8");
echo "\n\t<td class='lr'>Gemeinde</td>\n\t<td class='lr' colspan='3'>";
if ($showkey) {echo "<span class='key'>(".$gemeinde.")</span> ";}
// Link zur FS-Historie (passt nicht ganz in die Zeile "Gemeinde", aber gut unter "weitere Auskunft")
echo $gnam."</td>\n\t<td class='nwlink'>"
	."\n\t\t<p class='nwlink noprint'>"
		."\n\t\t\t<a href='alkisfshist.php?gkz=".$gkz."&amp;gmlid=".$gmlid;
			if ($showkey) {echo "&amp;showkey=j";}
			echo "' title='Vorg&auml;nger-Flurst&uuml;cke'>Historie "
			."<img src='ico/Flurstueck_Historisch.png' width='16' height='16' alt=''>"
		."</a>"
	."\n\t\t</p>"
. "\n\t</td>\n</tr>";
pg_free_result($res);

// K r e i s
$sql="SELECT bezeichnung FROM ax_kreisregion WHERE regierungsbezirk= $1 AND kreis= $2 AND endet IS NULL;"; 
$v = array($bezirk,$kreis);
$res = pg_prepare("", $sql);
$res = pg_execute("", $v);
if (!$res) {
	echo "\n<p class='err'>Fehler bei Kreis</p>";
	if ($debug > 2) {echo "\n<p class='dbg'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."</p>";}
}
$row = pg_fetch_array($res);
$knam = htmlentities($row["bezeichnung"], ENT_QUOTES, "UTF-8");
echo "\n<tr>\n\t<td>&nbsp;</td>\n\t<td>Kreis</td>\n\t<td class='lr' colspan='3'>";
if ($showkey) {echo "<span class='key'>(".$kreis.")</span> ";}
echo $knam."</td>\n\t<td>&nbsp;</td>\n</tr>";
pg_free_result($res);

// R e g - B e z
$sql="SELECT bezeichnung FROM ax_regierungsbezirk WHERE regierungsbezirk= $1 AND endet IS NULL;";
$v = array($bezirk);
$res = pg_prepare("", $sql);
$res = pg_execute("", $v);
if (!$res) {
	echo "\n<p class='err'>Fehler bei Regierungsbezirk</p>";
	if ($debug > 2) {echo "\n<p class='dbg'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."</p>";}
}
$row=pg_fetch_array($res);
$bnam=htmlentities($row["bezeichnung"], ENT_QUOTES, "UTF-8");
echo "\n<tr>\n\t<td>&nbsp;</td>\n\t<td>Regierungsbezirk</td>\n\t<td class='lr' colspan='3'>";
if ($showkey) {echo "<span class='key'>(".$bezirk.")</span> ";}
echo $bnam."</td>\n\t<td>&nbsp;</td>\n</tr>";
pg_free_result($res);
// ENDE G e b i e t s z u g e h o e r i g k e i t

// ** L a g e b e z e i c h n u n g **

// Lagebezeichnung MIT Hausnummer
// ax_flurstueck  >weistAuf>  AX_LagebezeichnungMitHausnummer
$sql="SELECT DISTINCT l.gml_id, l.gemeinde, l.lage, l.hausnummer, s.bezeichnung 
FROM ax_flurstueck f JOIN ax_lagebezeichnungmithausnummer l ON l.gml_id=ANY(f.weistauf)  
JOIN ax_lagebezeichnungkatalogeintrag s ON l.land=s.land AND l.regierungsbezirk=s.regierungsbezirk AND l.kreis=s.kreis AND l.gemeinde=s.gemeinde AND l.lage=s.lage 
WHERE f.gml_id= $1 AND f.endet IS NULL AND l.endet IS NULL AND s.endet IS NULL    
ORDER BY l.gemeinde, l.lage, l.hausnummer;";

$v = array($gmlid);
$res = pg_prepare("", $sql);
$res = pg_execute("", $v);

if (!$res) {
	echo "\n<p class='err'>Fehler bei Lagebezeichnung mit Hausnummer</p>";
	if ($debug > 1) {
		echo "\n<p class='dbg'>Fehler:".pg_last_error()."</p>";
		if ($debug > 2) {echo "\n<p class='dbg'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."<br>$1 = gml_id = '".$gmlid."'</p>";}
	}
} else {
	$j=0;
	while($row = pg_fetch_array($res)) {
		$sname = htmlentities($row["bezeichnung"], ENT_QUOTES, "UTF-8"); // Str.-Name
		echo "\n<tr>\n\t";
			if ($j == 0) {
				echo "\n\t<td class='ll'><img src='ico/Lage_mit_Haus.png' width='16' height='16' alt=''> Adresse:</td>";
			} else {
				echo "\n\t<td>&nbsp;</td>";
			}
			echo "\n\t<td>&nbsp;</td>"
			."\n\t<td class='lr' colspan='3'>";
			if ($showkey) {
				echo "<span class='key' title='Straßenschl&uuml;ssel'>(".$row["lage"].")</span>&nbsp;";
			}
			echo $sname."&nbsp;".$row["hausnummer"]."</td>"
			."\n\t<td>\n\t\t<p class='nwlink noprint'>"
				."\n\t\t\t<a title='Lagebezeichnung mit Hausnummer' href='alkislage.php?gkz=".$gkz."&amp;ltyp=m&amp;gmlid=".$row["gml_id"];
				if ($showkey) {echo "&amp;showkey=j";}
				echo "'>Lage <img src='ico/Lage_mit_Haus.png' width='16' height='16' alt=''></a>"
			."\n\t\t</p>\n\t</td>"
		."\n</tr>";
		$j++;
	}
	$cnt_adressen=$j;
	pg_free_result($res);
}
// +++ Verbesserung: mehrere HsNr zur gleichen Straße als Liste?

// Lagebezeichnung OHNE Hausnummer  (Gewanne oder nur Strasse)
// ax_flurstueck  >zeigtAuf>  AX_LagebezeichnungOhneHausnummer
$sql ="SELECT l.gml_id, l.unverschluesselt, l.gemeinde, l.lage, s.bezeichnung 
FROM ax_flurstueck f JOIN ax_lagebezeichnungohnehausnummer l ON l.gml_id=ANY(f.zeigtauf) 
LEFT JOIN ax_lagebezeichnungkatalogeintrag s ON l.land=s.land AND l.regierungsbezirk=s.regierungsbezirk AND l.kreis=s.kreis AND l.gemeinde=s.gemeinde AND l.lage=s.lage 
WHERE f.gml_id = $1 AND f.endet IS NULL AND l.endet IS NULL AND s.endet IS NULL;";

$v = array($gmlid);
$res = pg_prepare("", $sql);
$res = pg_execute("", $v);
if (!$res) {
	echo "\n<p class='err'>Fehler bei Lagebezeichnung ohne Hausnummer</p>";
	//if ($debug > 1) {echo "<p class='dbg'>Fehler:".pg_result_error($res)."</p>";}
	if ($debug > 2) {echo "\n<p class='dbg'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."<br>$1 = gml_id = '".$gmlid."'</p>";}
}
$j=0;
// Es wird auch eine Zeile ausgegeben, wenn kein Eintrag gefunden!
while($row = pg_fetch_array($res)) {
	$gewann = htmlentities($row["unverschluesselt"], ENT_QUOTES, "UTF-8");
	$skey=$row["lage"]; // Strassenschl.
	$lgml=$row["gml_id"]; // key der Lage
	if (!$gewann == "") {
		echo "\n<tr>"
			."\n\t<td class='ll' title='Lagebezeichnung'><img src='ico/Lage_Gewanne.png' width='16' height='16' alt=''> Gewanne:</td>"
			."\n\t<td></td>"
			."\n\t<td class='lr' colspan='3'>".$gewann."</td>"
			."\n\t<td>\n\t\t<p class='nwlink noprint'>"
				."\n\t\t\t<a title='Lagebezeichnung Ohne Hausnummer' href='alkislage.php?gkz=".$gkz."&amp;ltyp=o&amp;gmlid=".$lgml;
				if ($showkey) {echo "&amp;showkey=j";}				
				echo "'>\n\t\t\tLage <img src='ico/Lage_Gewanne.png' width='16' height='16' alt=''></a>"
			."\n\t\t</p>\n\t</td>"
		."\n</tr>";
	}
	// Gleicher DB-Eintrag in zwei HTML-Zeilen, besser nur ein Link
	if ($skey > 0) {
		echo "\n<tr>"
			."\n\t<td class='ll'><img src='ico/Lage_an_Strasse.png' width='16' height='16' alt=''> Stra&szlig;e:</td>"
			."\n\t<td></td>"
			."\n\t<td class='lr' colspan='3'>";
			if ($showkey) {
				echo "<span class='key'>(".$skey.")</span>&nbsp;";
			}
			echo $row["bezeichnung"]."</td>"
			."\n\t<td>\n\t\t<p class='nwlink noprint'>"
				."\n\t\t\t<a title='Lagebezeichnung Ohne Hausnummer' href='alkislage.php?gkz=".$gkz."&amp;ltyp=o&amp;gmlid=".$lgml;
				if ($showkey) {echo "&amp;showkey=j";}				
				echo "'>\n\t\t\tLage <img src='ico/Lage_an_Strasse.png' width='16' height='16' alt=''>\n\t\t\t</a>"
			."\n\t\t</p>\n\t</td>"
		."\n</tr>";
	}
	$j++;
}
pg_free_result($res);
// ENDE  L a g e b e z e i c h n u n g

// ** N U T Z U N G ** Gemeinsame Fläche von NUA und FS
// Tabellenzeilen (3 Spalten) mit tats. Nutzung zu einem FS ausgeben

/* N U T Z U N G   C l a s s i c (alt)
$sql ="SELECT m.title, m.fldclass, m.fldinfo, n.gml_id, n.nutz_id, n.class, n.info, n.zustand, n.name, n.bezeichnung, m.gruppe, 
st_area(st_intersection(n.wkb_geometry,f.wkb_geometry)) AS schnittflae, c.label, c.blabla 
FROM ax_flurstueck f, nutzung n JOIN nutzung_meta m ON m.nutz_id=n.nutz_id 
LEFT JOIN nutzung_class c ON c.nutz_id=n.nutz_id AND c.class=n.class 
WHERE f.gml_id= $1 AND st_intersects(n.wkb_geometry,f.wkb_geometry) = true 
AND st_area(st_intersection(n.wkb_geometry,f.wkb_geometry)) > 0.05 
AND f.endet IS NULL ORDER BY schnittflae DESC;";

$v = array($gmlid);
$res = pg_prepare("", $sql);
$res = pg_execute("", $v);
if (!$res) {
	echo "\n<p class='err'>Fehler bei Suche tats. Nutzung</p>";
	if ($debug > 2) {echo "\n<p class='dbg'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."<br>$1 = gml_id = '".$gmlid."'</p>";}
}
$the_Xfactor=$fsbuchflae / $fsgeomflae; // geom. ermittelte Fläche auf amtl. Buchfläche angleichen
$j=0;
while($row = pg_fetch_array($res)) {
	$grupp=$row["gruppe"]; // 4 Gruppen
	$nutzid=$row["nutz_id"]; // 27 Tabellen, num. Key
	$title=htmlentities($row["title"], ENT_QUOTES, "UTF-8"); // Titel der 27 Tabellen
	$fldclass=$row["fldclass"]; // Name 1. Zusatzfeld
	$fldinfo= $row["fldinfo"];  // Name 2. Zus.
	$gml=$row["gml_id"];
	$class=$row["class"]; // 1. Zusatzfeld verschlüsselt -> nutzung_class
	$info=$row["info"]; // 2. Zus. verschlüsselt (noch keine Info zum entschl.)
	$schnittflae=$row["schnittflae"];
	$label=$row["label"]; // Nutzungsart entschlüsselt
	$zus=$row["zustand"]; // im Bau
	$nam=$row["name"]; // Eigenname
	$bez=$row["bezeichnung"]; // weiterer Name (unverschl.)
	$blabla=htmlentities($row["blabla"], ENT_QUOTES, "UTF-8");
	$label=str_replace("/", "<br>", $label); // Ersetzt "/" durch html-Zeilenwechsel

	echo "\n<tr>\n\t";
		if ($j == 0) {
			echo "<td class='ll' title='Abschnitt der tats&auml;chlichen Nutzung'><img src='ico/Abschnitt.png' width='16' height='16' alt=''> Nutzung:</td>";
		} else {
			echo "<td>&nbsp;</td>";
		}
		$absflaebuch = $schnittflae * $the_Xfactor; // angleichen geometrisch an amtliche Fläche
		$schnittflae = number_format($schnittflae,1,",",".") . " m&#178;"; // geometrisch
		$absflaebuch = number_format($absflaebuch,0,",",".") . " m&#178;"; // Abschnitt an Buchfläche angeglichen
		echo "\n\t<td class='fla' title='geometrisch berechnet: ".$schnittflae."'>".$absflaebuch."</td>";

		echo "\n\t<td class='lr' colspan='3'>";
			if ($class == 0) {
				if ($showkey) {echo "<span class='key'>(".$nutzid.")</span> ";}
				echo $title; // Name der Tabelle
			} elseif ( ($fldclass == "Funktion" OR $fldclass == "Vegetationsmerkmal") AND $label != "") { // Kurze Anzeige
				if ($showkey) {echo "<span class='key' title='".$fldclass."'>(".$nutzid."-".$class.")</span> ";}
				if ($blabla = "") {
					echo $label;
				} else {
					echo "<span title='".$blabla."'>".$label."</span>";
				}
			} else { // ausfuehrlichere Anzeige
				echo $title; // NUA-Tabelle
				if ($class != "") { // NUA-Schlüssel
					echo ", ".$fldclass.": "; // Feldname
					if ($showkey) {echo "<span class='key' title='".$fldclass."'>(".$nutzid."-".$class.")</span> ";}
					if ($label != "") { // Bedeutung dazu wurde erfasst
						if ($blabla = "") {
							echo $label;
						} else {
							echo "<span title='".$blabla."'>".$label."</span>";
						}
					} else { // muss noch erfasst werden
						echo $class." "; // Schlüssel als Ersatz für Bedeutung
					}
				}
			}
			if ($info != "") { // manchmal ein zweites Zusatzfeld (wie entschlüsseln?)
				echo ", ".$fldinfo."=".$info;
			}
			if ($zus != "") { // Zustand
				echo "\n\t\t<br>";
				if ($showkey) {echo "<span class='key'>(".$zus.")</span> ";}
				echo "<span title='Zustand'>";				
				switch ($zus) {
					case 2100: echo "Außer Betrieb, stillgelegt, verlassen"; break;
					case 4000: echo "Im Bau"; break;
					case 8000: echo "Erweiterung, Neuansiedlung"; break;
					default: echo "Zustand: ".$zus; break;
				}
				echo "</span>";
			}
			if ($nam != "") {echo "<br>Name: ".$nam;}
			if ($bez != "") {echo "<br>Bezeichnung: ".$bez;}

		echo "</td>";
		echo "\n\t<td>";
			switch ($grupp) { // Icon nach 4 Objektartengruppen
				case "Siedlung":   $ico = "Abschnitt.png"; break;
				case "Verkehr":	   $ico = "Strassen_Klassifikation.png"; break;
				case "Vegetation": $ico = "Wald.png"; break;
				case "Gewässer":   $ico = "Wasser.png";	break;
				default:	$ico = "Abschnitt.png";	break;
			}
			// Icon ist auch im Druck sichtbar, class='noprint' ?		
			echo "<p class='nwlink'><img title='".$title."' src='ico/".$ico."' width='16' height='16' alt='NUA'></p>";
		echo "</td>";
	echo "\n</tr>";
	$j++;
}
  E N D E   N U T Z U N G   C l a s s i c  */

/* Status "Nutzung":

 Die Classic-Tabelle "nutzung" ist eine Zusammenfassung aller Tabellen mit Nutzungs-Flächen
 Die Classic-Tabelle "nutzung_meta" zeigt die Kategorie und Gruppe des Nutzungs-Abschnitts an.

 Aus der norGIS-Struktur wird ersatzweise VORLÄUFIG die Tabelle "nutz_21" verwendet,
 die das alte ALB-Format der Nutzungs-Abschnitte von Flurstücken simuliert.
 Hier finden sich bereits verschnittene Flächen, aber die gml_id fehlt.

 Die Entschlüsselung der Nutzungsart in den verschiedenen ALKIS-Varianten ist darin unterentwickelt.
 Diese ist eigentlich für jede der getrennten Tabellen der Gruppe Nutzungsart individuell.
 Die Classic-Lösung mit 2 Zusatzfeldern war schon sehr pauschalisiert, aber 
 durch die Rück-Konvertierung in ALB-Strukturen in der norGIS-Version ist das zu stark vereinfacht.
 z.B. wird "Wohnbaufläche" mit der Zusatzeigenschaft "Art der Bebauung": 'Offen'
 nun zur Nutzungsart "Offen".
 Durch JOIN auf die "alkis_elemente" mit einem Teil des Schlüssels wird das zur "Wohnbaufläche, Offen".
 Es sollte eine Tabellen-Struktur bereit gestellt werden, die auch aussagt, dass der Wert "Offen" zur
 Zusatz-Eigenschaft "Art der Bebauung" gehört. Dazu muss das PostProcessing erweitert werden. */


$sql="SELECT e.definition, trim(both FROM n.nutzsl) AS nutzsl, trim(both FROM n.fl) AS fl, trim(both FROM s.nutzung) AS nutzung
 FROM nutz_21 n JOIN nutz_shl s ON n.nutzsl = s.nutzshl
 JOIN alkis_elemente e ON e.kennung = substring(n.nutzsl from 1 for 5)
WHERE n.flsnr = $1 ORDER BY cast(n.fl AS integer) DESC;";
// Flurstueckskennzeichen mit Trennzeichen im ALB-Format wie 'llgggg-fff-zzzzz/nnn'
$fskennzalb=$defland.$gmkgnr."-".str_pad($flurnummer,3,"0",STR_PAD_LEFT)."-".str_pad($zaehler,5,"0",STR_PAD_LEFT)."/".str_pad($nenner,3,"0",STR_PAD_LEFT);
$v = array($fskennzalb);
$res = pg_prepare("", $sql);
$res = pg_execute("", $v);
if (!$res) {
	echo "\n<p class='err'>Fehler bei Suche tats. Nutzung</p>";
	if ($debug > 2) {echo "\n<p class='dbg'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."<br>$1 = FS-Kennz = '".$fskennzalb."'</p>";}
}

$j=0;
while($row = pg_fetch_array($res)) {
	$flae=$row["fl"]; // Buchfläche
	$nutzsl=$row["nutzsl"]; // Schlüssel
	$nutzung=$row["nutzung"]; // Bezeichnung aus ALB-Tabelle, "fein"
	$defi=$row["definition"]; // Langer Text mit Beschreibung
	$title=htmlentities($defi, ENT_QUOTES, "UTF-8"); // .. für Anzeige aufbereitet

	echo "\n<tr>\n\t";
		if ($j == 0) {
			echo "<td class='ll' title='Abschnitt der tats&auml;chlichen Nutzung'><img src='ico/Abschnitt.png' width='16' height='16' alt=''> Nutzung:</td>";
		} else {
			echo "<td>&nbsp;</td>";
		}
		$absflaebuch = number_format($flae,0,",",".") . " m&#178;"; // Formatierte Abschnitts-Buch-Fläche
		echo "\n\t<td class='fla' title='Buchfl&auml;che des Abschnitts'>".$absflaebuch."</td>";

		echo "\n\t<td class='lr' colspan='3' title='".$title."'>";
			if ($showkey) {echo "<span class='key'>(".$nutzsl.")</span> ";}
			echo $nutzung
		."</td>"
		."\n\t<td>";
/*		// Derzeit ist keine Gruppe zugeordnet
			switch ($grupp) { // Icon nach 4 Objektartengruppen
				case "Siedlung":   $ico = "Abschnitt.png"; break;
				case "Verkehr":	   $ico = "Strassen_Klassifikation.png"; break;
				case "Vegetation": $ico = "Wald.png"; break;
				case "Gewässer":   $ico = "Wasser.png";	break;
				default:	$ico = "Abschnitt.png";	break;
			}
			// Icon ist auch im Druck sichtbar, class='noprint' ?		
			echo "<p class='nwlink'><img title='".$title."' src='ico/".$ico."' width='16' height='16' alt='NUA'></p>";
*/
		echo "</td>"
	."\n</tr>";
	$j++;
}
pg_free_result($res);

echo "\n<tr>" // Summenzeile
	."\n\t<td class='re' title='amtliche Fl&auml;che (Buchfl&auml;che)'>Fl&auml;che:</td>"
	."\n\t<td class='fla sum'>"
	."<span title='geometrisch berechnete Fl&auml;che = ".$fsgeomflaed."' class='flae'>".$fsbuchflaed."</span></td>";

	// Flaeche und Link auf Gebäude-Auswertung
	echo "\n\t<td colspan='3'>&nbsp;</td>\n\t<td>"
		."\n\t\t<p class='nwlink noprint'>" // Gebaeude-Verschneidung
			."\n\t\t\t<a href='alkisgebaeudenw.php?gkz=".$gkz."&amp;gmlid=".$gmlid;
			if ($showkey) {echo "&amp;showkey=j";}
			if ($cnt_adressen > 0) { // wenn Adresse vorgekommen ist
				echo "' title='Geb&auml;udenachweis'>Geb&auml;ude ";
			} else { // Gebäude mit Adresse gibt es NICHT, das ist klar
				echo "' title='Suche Geb&auml;ude ohne Adresse auf dem Flurst&uuml;ck oder angrenzende Geb&auml;ude'>Suche ";
			}
			echo "<img src='ico/Haus.png' width='16' height='16' alt=''></a>"
		."\n\t\t</p>"
	."\n\t</td>"
."\n</tr>";
// ENDE  N U T Z U N G


// K L A S S I F I Z I E R U N G

// Klassifizierung nach  W a s s e rrecht
/* 
	// Tabelle immer leer?
$sql="SELECT h.v, w.artderfestlegung, st_area(st_intersection(w.wkb_geometry, f.wkb_geometry)) AS schnittflae, f.amtlicheflaeche, st_area(f.wkb_geometry) as fsgeomflae 
FROM ax_flurstueck f
JOIN ax_klassifizierungnachwasserrecht w
 ON st_intersects(w.wkb_geometry, f.wkb_geometry) AND st_area(st_intersection(w.wkb_geometry, f.wkb_geometry)) > 0.05
LEFT JOIN alkis_wertearten h
 ON cast(w.artderfestlegung AS character varying) = h.k AND h.element='ax_klassifizierungnachwasserrecht' AND h.bezeichnung='artderfestlegung'
WHERE f.gml_id = $1 AND f.endet IS NULL AND w.endet IS NULL ORDER BY schnittflae DESC";

$v = array($gmlid);
$res = pg_prepare("", $sql);
$res = pg_execute("", $v);
if (!$res) {echo "\n<p class='err'>Fehler bei DB-Abfrage zur Klassifizierung Wasser</p>\n";}

if(!empty($res) && pg_num_rows($res) > 0) {
	echo "\n<table>";
	while($row = pg_fetch_array($res)) {
		$fsbuchflae=$row["amtlicheflaeche"];
		$fsgeomflae=$row["fsgeomflae"];
		$the_Xfactor=$fsbuchflae / $fsgeomflae; // ++ nicht in Loop, ist konst. je FS
		$absflaebuch = $row['schnittflae'] * $the_Xfactor;
		echo"\n<tr><td></td><td></td></tr>"
		."\n<tr><td><b>Fläche</b></td><td class='klassifizerung'><span class=''>".number_format(intval($absflaebuch),0,",",".")." m²</span></td></tr>"	
		."\n<tr><td><b>Bezeichnung</b></td><td class='klassifizerung'><span class=''>".$row['v']."</span></td></tr>"
		."\n<tr><td></td><td></td></tr>";	
	}
	echo "</table>";
}
// Klassifizierung nach  S t r a ß e n recht
	// Tabelle immer leer?
*/

// B o d e n s c h ä t z u n g
// ---------------------------
// Tabelle "klas_3x" (norbit-ALB): Dort fehlen Bodenart und Zustandsstufe, es ist aber bereits auf Buchfläche umgerechnet.

$sql="SELECT 
 kulturart.k as kulturartk, kulturart.v as kulturartv, bodenart.k as bodenartk, bodenart.v as bodenartv, zustbod.v AS zustbodv,
 b.bodenzahlodergruenlandgrundzahl as bodenzahl, b.ackerzahlodergruenlandzahl AS ackerzahl, 
 b.jahreszahl, st_area(st_intersection(b.wkb_geometry, f.wkb_geometry)) AS schnittflae 
FROM ax_flurstueck f
JOIN ax_bodenschaetzung b ON st_intersects(b.wkb_geometry, f.wkb_geometry) AND st_area(st_intersection(b.wkb_geometry, f.wkb_geometry)) > 0.05
LEFT JOIN alkis_wertearten AS bodenart  ON cast(b.bodenart  AS character varying) = bodenart.k  AND bodenart.element='ax_bodenschaetzung'  AND bodenart.bezeichnung='bodenart'
LEFT JOIN alkis_wertearten AS kulturart ON cast(b.kulturart AS character varying) = kulturart.k AND kulturart.element='ax_bodenschaetzung' AND kulturart.bezeichnung='kulturart'
LEFT JOIN alkis_wertearten AS zustbod   ON cast(b.zustandsstufeoderbodenstufe AS character varying) = zustbod.k AND zustbod.element='ax_bodenschaetzung' AND zustbod.bezeichnung='zustandsstufeoderbodenstufe'
WHERE f.gml_id = $1 AND f.endet IS NULL AND b.endet IS NULL ORDER BY schnittflae DESC";

$v = array($gmlid);
$res = pg_prepare("", $sql);
$res = pg_execute("", $v);
if (!$res) {echo "\n<p class='err'>Fehler bei DB-Abfrage zur Klassifizierung Boden</p>\n";}

$gesertragsmz = 0; // Gesamt-ErtragsMesszahl
$klasflae = 0; // Summe klassifizierte Fläche
$j=0;
if(!empty($res) && pg_num_rows($res) > 0) {
	while ($row = pg_fetch_array($res)) {
		$kulturartk=$row['kulturartk']; // Key	-
		$kulturartv=$row['kulturartv']; //		- Value
		// 1000="Ackerland (A)", 2000="Acker-Grünland (AGr)", 3000="Grünland (Gr)", 4000="Grünland-Acker (GrA)" 		
		if (substr($kulturartv, 0, 3) == 'Ack') { // A
			$kbez1="Bodenzahl";
			$kbez2="Ackerzahl";
		} else { // Gr
			$kbez1="Gr&uuml;nlandgrundzahl";
			$kbez2="Gr&uuml;nlandzahl";
		}
		$absflae = $row['schnittflae'];
		$absbuchflae = $absflae * $the_Xfactor;
		$klasflae+=$absbuchflae;
		$ertragszahl = intval($absbuchflae * $row['ackerzahl'] / 100);
		$gesertragsmz+=$ertragszahl;
	//	$absflaedis = number_format($absflae,0,",",".")." m&#178;";  // als Tool-Tip ?
		$absbuchflaedis = number_format($absbuchflae,0,",",".")." m&#178;";
		$boedenzahl=ltrim($row['bodenzahl'], '0');
		$ackerzahl=ltrim($row['ackerzahl'], '0');

		// Sp. 1/4
		if ($j == 0) {
			echo "\n<tr>\n\t<td class='ll' title='Abschnitt Bodensch&auml;tzung'><img src='ico/Landwirt.png' width='16' height='16' alt=''> Bodensch&auml;tzung:</td>";
		} else {
			echo "\n<tr>\n\t<td>&nbsp;</td>";
		}

		// Sp. 2/4
		echo "\n\t<td class='fla' title='Ertragsmesszahl: Produkt von ".$kbez2."/100 und Fl&auml;che.'>EMZ ".$ertragszahl."</td>";

		// Sp. 3/4 - unterteilt in 3 Sp.
		echo "\n\t<td class='re' title='Fl&auml;che des Sch&auml;tzungsabschnitts'>".$absbuchflaedis."</td>";
		echo "\n\t<td class='lr'><span title='".$kbez1."'>".$boedenzahl."</span>/<span title='".$kbez2."'>".$ackerzahl."</span></td>";
		echo "\n\t<td class='lr'>";
			if ($showkey) {echo "\n\t\t<span class='key'>(".$kulturartk.")</span> ";}
			echo "\n\t\t<span title='Kulturart'>".$kulturartv."</span> ";
			if ($showkey) {echo "\n\t\t<span class='key'>(".$row['bodenartk'].")</span> ";}
			echo "\n\t\t<span title='Bodenart'>".$row['bodenartv']."</span> ";
			echo "\n\t\t<span title='Zustandsstufe'>".$row['zustbodv']."</span>";
			if (isset($row['jahreszahl'])) {echo "\n\t\t <span title='Jahreszahl'>".$row['jahreszahl']."</span>";}
		//	++ Entstehungsart (Array) derzeit leer. 1:N entschlüsseln. entstehungsartoderklimastufewasserverhaeltnisse
		// $ent = explode(",", trim($entsteh, "{}") ); // [] --> PHP-Array
		//	if (isset($row['sonstiges'])) {echo "\n\t\t, <span title='Sonstige Angaben'>".$row['sonstiges']."</span>";} -- immer leer (Konverter-Fehler?)
		echo "\n\t</td>";

		// Sp. 4/4 - leer, keine Links
		echo "\n\t<td>&nbsp;</td>\n</tr>";
		$j++;
	}
	// Summenzeile
	$klasflaedis = number_format($klasflae,0,",",".")." m&#178;";
	echo "\n<tr>\n\t<td class='re'>Ertragsmesszahl:</td>"
	."\n\t<td class='fla sum' title='Summe der Ertragsmesszahlen f&uuml;r dies Flurst&uuml;ck'>".$gesertragsmz."</td>"
	."\n\t<td class='re'>".$klasflaedis."</td>\n\t<td colspan='3'>&nbsp;</td>\n</tr>";
}

// H i n w e i s  auf Bodenneuordnung oder eine strittige Grenze
// b.name, b.artderfestlegung, 
$sql_boden ="SELECT a.k AS wert, a.v AS art_verf, b.gml_id AS verf_gml, b.bezeichnung AS verf_bez, 
b.name AS verf_name, d.bezeichnung AS stelle_bez, d.stelle AS stelle_key 
FROM ax_bauraumoderbodenordnungsrecht b 
LEFT JOIN alkis_wertearten a ON cast(b.artderfestlegung AS character varying)=a.k AND a.element='ax_bauraumoderbodenordnungsrecht' AND a.bezeichnung='artderfestlegung'
LEFT JOIN ax_dienststelle d ON b.stelle=d.stelle 
WHERE b.endet IS NULL AND d.endet IS NULL  
AND (ST_Within((SELECT wkb_geometry FROM ax_flurstueck WHERE gml_id = $1 AND endet IS NULL ), wkb_geometry)
 OR ST_Overlaps((SELECT wkb_geometry FROM ax_flurstueck WHERE gml_id = $1 AND endet IS NULL), wkb_geometry));";

pg_prepare($con, "bodeneuordnung", $sql_boden);
$res_bodeneuordnung = pg_execute($con, "bodeneuordnung", array($gmlid));
if (!$res_bodeneuordnung) {
	echo "\n<p class='err'>Fehler bei Bau-, Raum- oder Bodenordnungsrecht</p>";
	if ($debug > 2) {echo "\n<p class='dbg'>SQL=<br>".$sql_boden."<br>$1 = gml_id = '".$gmlid."'</p>";}
}

$sql_str="SELECT gml_id FROM ax_besondereflurstuecksgrenze WHERE endet IS NULL AND 1000 = ANY(artderflurstuecksgrenze) 
AND ST_touches((SELECT wkb_geometry FROM ax_flurstueck WHERE gml_id = $1 AND endet IS NULL),wkb_geometry);";

pg_prepare($con, "strittigeGrenze", $sql_str);
$res_strittigeGrenze = pg_execute($con, "strittigeGrenze", array($gmlid));
if (!$res_strittigeGrenze) {
	echo "\n<p class='err'>Fehler bei strittige Grenze</p>";
	if ($debug > 2) {echo "\n<p class='dbg'>SQL=<br>".$sql_str."<br>$1 = gml_id = '".$gmlid."'</p>";}
}

if (pg_num_rows($res_bodeneuordnung) > 0 OR pg_num_rows($res_strittigeGrenze) > 0) {
	echo "\n<tr>"
	."\n\t<td title='Hinweise zum Flurst&uuml;ck'><h6><img src='ico/Hinweis.png' width='16' height='16' alt=''> "
	."Hinweise:</h6></td>\n\t<td colspan='5'>&nbsp;</td>"
	."\n</tr>";

	if (pg_num_rows($res_bodeneuordnung) > 0) {

		while ($row = pg_fetch_array($res_bodeneuordnung)) { // 3 Zeilen je Verfahren

			// Zeile 1 - kommt immer, darum hier den Link
			echo "\n<tr title='Bau-, Raum- oder Bodenordnungsrecht'>"
				."\n\t<td>Bodenrecht</td>"
				."\n\t<td class='re'>Festlegung: </td>" // "Art der Festlegung" zu lang
				."\n\t<td colspan='3'>";
					if ($showkey) {echo "<span class='key'>(".$row['wert'].")</span> ";}
					echo $row['art_verf']
				."</td>";
				// LINK:
				echo "\n\t<td>"
					."\n\t\t<p class='nwlink noprint'>"
					."\n\t\t\t<a href='alkisbaurecht.php?gkz=".$gkz."&amp;gmlid=".$row['verf_gml'];
					if ($showkey) {echo "&amp;showkey=j";}
					echo "' title='Bau-, Raum- oder Bodenordnungsrecht'>Recht <img src='ico/Gericht.png' width='16' height='16' alt=''></a>"
					."\n\t\t</p>"		
				."\n\t</td>"
			."\n</tr>";

			// Zeile 2
			$dstell=$row['stelle_key'];
			if ($dstell != "") { // Kann auch leer sein
				echo "\n<tr title='Flurbereinigungsbeh&ouml;rde'>"
					."\n\t<td>&nbsp;</td>"
					."\n\t<td class='re'>Dienststelle: </td>"
					."\n\t<td colspan='3'>";
						if ($showkey) {echo "<span class='key'>(".$dstell.")</span> ";}
						echo $row['stelle_bez']
					."</td>"
					."\n\t<td>&nbsp;</td>"
				."\n</tr>";
			}

			// Zeile 3
			$vbez=$row['verf_bez']; // ist nicht immer gefüllt
			$vnam=$row['verf_name']; // noch seltener
			if ($vbez != "") {
				echo "\n<tr title='Verfahrensbezeichnung'>"
					."\n\t<td>&nbsp;</td>"
					."\n\t<td class='re'>Verfahren: </td>"
					."\n\t<td colspan='3'>";
						if ($vnam == "") {
							echo $vbez; // nur die Nummer
						} else {	// Name oder beides
							if ($showkey) {echo "<span class='key'>(".$vbez.")</span> ";}
							echo $vnam;
						}
		 			echo "</td>"
					."\n\t<td>&nbsp;</td>"
				."\n</tr>";
			}
		}
	}
	if (pg_num_rows($res_strittigeGrenze) > 0) { // 1 Zeile
		echo "\n<tr>\n<td>Strittige Grenze:</td>"
		."<td colspan=4>Mindestens eine Flurst&uuml;cksgrenze ist als <b>strittig</b> zu bezeichnen. Sie kann nicht festgestellt werden, weil die Beteiligten sich nicht &uuml;ber den Verlauf einigen. Nach sachverst&auml;ndigem Ermessen der Katasterbeh&ouml;rde ist anzunehmen, dass das Liegenschaftskataster nicht die rechtm&auml;&szlig;ige Grenze nachweist.</td>"
		."\n<td>&nbsp;</td>\n</tr>";
	}
}
echo "\n</table>";

// G R U N D B U C H
echo "\n\n<table class='outer'>"
	."\n<tr>"
		."\n\t<td>"
			."\n\t\t<h3 id='gb'><img src='ico/Grundbuch_zu.png' width='16' height='16' alt=''> Grundb&uuml;cher</h3>"
		."\n\t</td>"
		."\n\t<td>"
			."\n\t\t<p class='nwlink noprint'>"
				."\n\t\t\t<a href='".$_SERVER['PHP_SELF']. "?gkz=".$gkz."&amp;gmlid=".$gmlid."&amp;berbu=".$berbu;
				if ($showkey) {echo "&amp;showkey=j";}

				// Umschalter: FS-Nachweis ruft sich selbst mit geaendertem Parameter auf. Positionierung auf Marke "#gb"
				if ($eig=="j") {
					echo "&amp;eig=n#gb' title='Flurst&uuml;cksnachweis'>ohne Eigent&uuml;mer</a>";
				} else {
					echo "&amp;eig=j#gb' title='Flurst&uuml;cks- und Eigent&uuml;mernachweis'>mit Eigent&uuml;mer "
					."<img src='ico/EigentuemerGBzeile.png' width='16' height='16' alt=''></a>";
				}
			echo "\n\t\t</p>"
		."\n\t</td>"
	."\n</tr>"
."\n</table>";

// B U C H U N G S S T E L L E N  zum FS (istGebucht)
$sql ="SELECT s.gml_id, s.buchungsart, s.laufendenummer as lfd, s.zaehler, s.nenner, s.nummerimaufteilungsplan as nrpl, s.beschreibungdessondereigentums as sond, b.v AS bart, b.d AS barttitle
FROM ax_flurstueck f JOIN ax_buchungsstelle s ON s.gml_id=f.istgebucht 
LEFT JOIN alkis_wertearten b ON cast(s.buchungsart AS character varying)=b.k AND b.element='ax_buchungsstelle' AND b.bezeichnung='buchungsart'
WHERE f.gml_id= $1 AND f.endet IS NULL AND s.endet IS NULL ORDER BY s.laufendenummer;";

$v = array($gmlid);
$ress = pg_prepare("", $sql);
$ress = pg_execute("", $v);
if (!$ress) {
	echo "\n<p class='err'>Keine Buchungsstelle.</p>";
	if ($debug > 1) {
		echo "<p class='dbg'>Fehler:".pg_result_error($ress)."</p>";
		if ($debug > 2) {echo "\n<p class='dbg'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."<br>$1 = gml_id = '".$gmlid."'</p>";}
	}
}
$bs=0; // Z.BuchungsStelle
while($rows = pg_fetch_array($ress)) {  // Schleife Buchungs-Stelle
	$gmls=$rows["gml_id"]; // gml b-Stelle
	$lfd=$rows["lfd"]; // BVNR
	$barttitle=htmlentities($rows["barttitle"], ENT_QUOTES, "UTF-8"); // .. für Anzeige aufbereitet

	// B U C H U N G S B L A T T  zur Buchungsstelle (istBestandteilVon)
	$sql="SELECT b.gml_id, b.bezirk, b.buchungsblattnummermitbuchstabenerweiterung as blatt, b.blattart, wb.v AS blattartv, wb.d AS blattartd, z.bezeichnung 
	FROM ax_buchungsstelle s JOIN ax_buchungsblatt b ON b.gml_id=s.istbestandteilvon 
	LEFT JOIN ax_buchungsblattbezirk z ON z.land=b.land AND z.bezirk=b.bezirk 
	LEFT JOIN alkis_wertearten wb ON cast(b.blattart AS character varying)=wb.k AND wb.element='ax_buchungsblatt' AND wb.bezeichnung='blattart' 
	WHERE s.gml_id = $1 AND s.endet IS NULL AND b.endet IS NULL AND z.endet IS NULL
	ORDER BY b.bezirk, b.buchungsblattnummermitbuchstabenerweiterung ;";

	$v=array($gmls);
	$resg=pg_prepare("", $sql);
	$resg=pg_execute("", $v);
	if (!$resg) {
		echo "\n<p class='err'>Kein Buchungsblatt.</p>";
		if ($debug > 2) {echo "\n<p class='dbg'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."<br>$1 = gml_id = '".$gmls."'</p>";}
	}
	$bl=0; // Z.Blatt
	while($rowg = pg_fetch_array($resg)) {
		$gmlg=$rowg["gml_id"];
		$beznam=$rowg["bezeichnung"];
		$blattkeyg=$rowg["blattart"]; // Key
		$blattartg=$rowg["blattartv"]; // Value
		$blatt=$rowg["blatt"];
		echo "\n<hr>"
		."\n<table class='outer'>"
		."\n<tr>"; // 1 row only
			echo "\n\t<td>"; // Outer linke Spalte:

				// Rahmen mit GB-Kennz
				if ($blattkeyg == 1000) {
					echo "\n\t\t<table class='kennzgb' title='Bestandskennzeichen'>";
				}else {
					echo "\n\t\t<table class='kennzgbf' title='Bestandskennzeichen'>"; // GB fiktiv = Rahmen dotted
				}
					echo "\n\t\t<tr>\n\t\t\t<td class='head'>Bezirk</td>"
						."\n\t\t\t<td class='head' title='".$rowg["blattartd"]."'>";
						if ($showkey) {echo "<span class='key'>".$blattkeyg."</span>&nbsp;";}
						echo $blattartg."</td>"
						."\n\t\t\t<td class='head'>Lfd-Nr.</td>"
						."\n\t\t\t<td class='head'>Buchungsart</td>"
					."\n\t\t</tr>"
					."\n\t\t<tr>"
						."\n\t\t\t<td title='Grundbuchbezirk'>";
						if ($showkey) {echo "<span class='key'>".$rowg["bezirk"]."</span><br>";}
						echo $beznam."&nbsp;</td>"
						."\n\t\t\t<td title='Grundbuch-Blatt'><span class='wichtig'>".$blatt."</span></td>"
						."\n\t\t\t<td title='Bestandsverzeichnis-Nummer (BVNR, Grundst&uuml;ck)'>".$lfd."</td>"
						."\n\t\t\t<td title='".$barttitle."'>";
						if ($showkey) {echo "<span class='key'>".$rows["buchungsart"]."</span><br>";}
						echo $rows["bart"]."</td>"
					."\n\t\t</tr>"
				."\n\t\t</table>";

				// Miteigentumsanteil
				if ($rows["zaehler"] <> "") {
					echo "\n<p class='ant'>".$rows["zaehler"]."/".$rows["nenner"]."&nbsp;Anteil am Flurst&uuml;ck</p>";
				}
			echo "\n\t</td>\n\t<td>"; // Outer rechte Spalte: NW-Links

				echo "\n\t\t<p class='nwlink noprint'>weitere Auskunft:<br>";
					if ($showkey) {echo "<span class='key'>".$blattkeyg."</span> ";}
					echo "\n\t\t\t<a href='alkisbestnw.php?gkz=".$gkz."&amp;gmlid=".$gmlg;
						if ($showkey) {echo "&amp;showkey=j";}
						echo "#bvnr".$lfd; // Die # hinter die &-Paramter
						if ($blattkeyg == 1000) {
							echo "' title='Grundbuchnachweis mit kompletter Eigent&uuml;merangabe'>";
						} else {
							echo "' title='Grundbuchnachweis'>";
						}
						echo $blattartg." <img src='ico/GBBlatt_link.png' width='16' height='16' alt=''>"
					."</a>"
				."\n\t\t</p>";

				// berechtigte Buchungstellen (im rechten Teil der äußeren Tab.
				$cnt_ber = ber_bs_hinw($gmls, $gmlid); // Hinweis ausgeben, zählen

			echo "\n\t</td>" // ende aussen rechts
		."\n</tr>"
		."\n</table>";

		// +++ Weitere Felder ausgeben? BeschreibungDesUmfangsDerBuchung
		if ($rows["sond"] != "") {
			echo "\n<p class='sond' title='Sondereigentum'>Verbunden mit dem Sondereigentum<br>".$rows["sond"]."</p>";
		}
		if ($rows["nrpl"] != "") {
			echo "\n<p class='nrap' title='Nummer im Aufteilungsplan'>Nummer <span class='wichtig'>".$rows["nrpl"]."</span> im Aufteilungsplan.</p>";
		}

		// E I G E N T U E M E R, zum GB
		// Person <-benennt< AX_Namensnummer  >istBestandteilVon-> AX_Buchungsblatt
		if ($eig=="j") { // Wahlweise mit/ohne Eigentümer
			$n = eigentuemer($gmlg, false, ""); // hier ohne Adresse
 			if ($n == 0) {
				if ($blattkeyg == 1000) {
					echo "\n<p class='err'>Keine Namensnummer gefunden.</p>";
				} else {
					echo "\n<p>ohne Eigent&uuml;mer.</p>";
				}
			}
		}

		// B e r e c h t i g t e   B u c h u n g e n  ... zu dieser Buchungs-Stelle. Optional.
		if ($berbu=="j") { // Wahlweise anzeigen
			echo "\n<hr>\n<h3 id='berbu'><img src='ico/Grundbuch.png' width='16' height='16' alt=''> Berechtigte Buchungen</h3>"
			."\n<p>".$cnt_ber." Buchungen mit Rechten an der Buchung ".$lfd." auf ".$blattartg." ".$blatt." von ".$beznam.":</p>";
			ber_bs_anz($gmls, $eig); // berechtigte Buchungstellen und GB-Blätter Anzeigen, und ggf. auch mit Eigentümer
		}
		$bl++; // Zähl Blatt
	}
	if ($bl == 0) {echo "\n<p class='err'>Kein Buchungsblatt zur Buchungstelle gefunden.</p>";}
	$bs++; // Zähl Buchungs-Stelle
}

pg_free_result($resg);
if ($bs == 0) {echo "\n<p class='err'>Keine Buchungstelle zum Flurst&uuml;ck gefunden.</p>";}
pg_close($con);
echo <<<END

<div class='buttonbereich noprint'>
<hr>
	<a title="zur&uuml;ck" href='javascript:history.back()'><img src="ico/zurueck.png" width="16" height="16" alt="zur&uuml;ck"></a>&nbsp;
	<a title="Drucken" href='javascript:window.print()'><img src="ico/print.png" width="16" height="16" alt="Drucken"></a>&nbsp;
	<a title="Export als CSV" href='javascript:ALKISexport()'><img src="ico/download_fs.png" width="32" height="16" alt="Export"></a>&nbsp;
</div>
END;
footer($gmlid, $_SERVER['PHP_SELF']."?", "&amp;eig=".$eig."&amp;berbu=".$berbu);
?>
</body>
</html>