<?php
/*	alkislage.php

	ALKIS-Buchauskunft, Kommunales Rechenzentrum Minden-Ravensberg/Lippe (Lemgo).
	Kann die 3 Arten von Lagebezeichnung anzeigen und verbundene Objekte verlinken

	Version:
	2016-02-24 Version fuer norGIS-ALKIS-Import
	2016-03-14 Korrekturen
	2016-11-29 HTML5, Gemeinsam genutzte Datenbanken ermöglichen
	2017-06-08 Validierung Eingabeparameter, gestreifte Tabelle, Feinkorrekturen
	2017-10-09 Sauber filtern auf endet IS NULL

	ToDo:
	- Balken-Kennzeichen kompatibel machen mit der Eingabe der Navigation für Adresse
	- das Modul "alkisgebaeudenw" (alle Geb. auf einem FS) verschneidet die Flächen und findet damit auch 
	Grenz-Uberbauungen und angrenzende Gebäude. Diese fehlen hier, weil nur Verknüpfungen verarbeitet werden.
	Mit Flächen-Verschneidung auch weitere FS anzeigen?
*/
session_start();

$showkey="n"; // Var. aus Parameter initalisieren
$cntget = extract($_GET); // Parameter in Variable umwandeln

// strikte Validierung aller Parameter
if (!isset($gmlid) or !preg_match('#^[0-9A-Za-z]{16}$#', $gmlid)) {die("Eingabefehler gmlid");}
if (!isset($gkz) or !preg_match('#^[0-9]{3}$#', $gkz)) {die("Eingabefehler gkz");}
if (!preg_match('#^[j|n]{0,1}$#', $showkey)) {die ("Eingabefehler showkey");}
if ($showkey == "j") {$showkey=true;} else {$showkey=false;}
if (!preg_match('#^[m|p|o]{1}$#', $ltyp)) {die ("Eingabefehler ltyp");}

require_once("alkis_conf_location.php");
if ($auth == "mapbender") {require_once($mapbender);}
include("alkisfkt.php");

switch ($ltyp) {
	case "m": // "Mit HsNr" = Hauptgebaeude
		$tnam = "ax_lagebezeichnungmithausnummer"; break;
	case "p": // "mit PseudoNr" = Nebengebaeude
		$tnam = "ax_lagebezeichnungmitpseudonummer";	break;
	case "o": //"Ohne HsNr" = Gewanne oder Strasse
		$tnam = "ax_lagebezeichnungohnehausnummer"; break;
	default:
		$ltyp = "m";
		$tnam = "ax_lagebezeichnungmithausnummer"; break;
}
?>
<!doctype html>
<html lang="de">
<head>
	<meta charset="utf-8">
	<meta name="viewport" content="width=device-width, initial-scale=1.0">
	<title>ALKIS Lagebezeichnung</title>
	<link rel="stylesheet" type="text/css" href="alkisauszug.css">
	<link rel="shortcut icon" type="image/x-icon" href="ico/Lage_mit_Haus.ico">
</head>
<body>
<?php
$con = pg_connect($dbconn." options='--application_name=ALKIS-Auskunft_alkislage.php'");
if (!$con) echo "\n<p class='err'>Fehler beim Verbinden der DB</p>";

// L a g e b e z e i c h n u n g
$sql ="SELECT s.gml_id AS strgml, s.bezeichnung AS snam, b.bezeichnung AS bnam, r.bezeichnung AS rnam, k.bezeichnung AS knam, g.bezeichnung AS gnam, l.land, l.regierungsbezirk, l.kreis, l.gemeinde, l.lage, ";
switch ($ltyp) {
	case "m": // "Mit HsNr"
		$sql.="l.hausnummer ";
	break;
	case "p": // "mit PseudoNr"
		$sql.="l.pseudonummer, l.laufendenummer ";
	break;
	case "o": //"Ohne HsNr"
		$sql.="l.unverschluesselt ";
	break;
}
// "Left" weil: Bei sub-Typ "Gewanne" von Typ "o" sind keine Schlüsselfelder gefüllt!
$sql.="FROM ".$tnam." l 
LEFT JOIN ax_gemeinde g ON l.land=g.land AND l.regierungsbezirk=g.regierungsbezirk AND l.kreis=g.kreis AND l.gemeinde=g.gemeinde 
LEFT JOIN ax_kreisregion k ON l.land=k.land AND l.regierungsbezirk=k.regierungsbezirk AND l.kreis=k.kreis 
LEFT JOIN ax_regierungsbezirk r ON l.land=r.land AND l.regierungsbezirk=r.regierungsbezirk 
LEFT JOIN ax_bundesland b ON l.land=b.land 
LEFT JOIN ax_lagebezeichnungkatalogeintrag s 
ON l.land=s.land AND l.regierungsbezirk=s.regierungsbezirk AND l.kreis=s.kreis AND l.gemeinde=s.gemeinde AND l.lage=s.lage 
WHERE l.gml_id= $1 AND l.endet IS NULL AND g.endet IS NULL AND k.endet IS NULL AND r.endet IS NULL AND b.endet IS NULL AND s.endet IS NULL;";

$v = array($gmlid);
$res = pg_prepare("", $sql);
$res = pg_execute("", $v);
if (!$res) {
	echo "\n<p class='err'>Fehler bei Lagebezeichnung.</p>";
	if ($debug > 2) {echo "\n<p class='err'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."<br>$1 = gml_id = '".$gmlid."'</p>";}
}

if ($row = pg_fetch_array($res)) {
	$strgml=$row["strgml"]; // gml_id des Katalogeintrag Straße
	$land =$row["land"];
	$regbez=$row["regierungsbezirk"];
	$kreis=$row["kreis"];
	$knam=$row["knam"];
	$rnam=$row["rnam"];
	$bnam=$row["bnam"];
	$gem=$row["gemeinde"];
	$gnam=$row["gnam"];
	$lage=$row["lage"]; // Strassenschluessel
	$snam=$row["snam"]; //Strassennamen
//	$kennz=$land."-".$regbez."-".$kreis.  ...
	$kennz=$gem."-".$lage."-"; // ToDo: Kompatibel machen als Eingabe in Navigation/Adresse 
	
	switch ($ltyp) {
		case "m": // "Mit HsNr"
			$hsnr=$row["hausnummer"];
			$kennz.=$hsnr;
			$untertitel="Hauptgeb&auml;ude mit Hausnummer";
			echo "\n<p class='lage'>ALKIS Lagebezeichnung mit Hausnummer ".$kennz."&nbsp;</p>"; // Balken
			$osub="";
		break;
		case "p": // "mit PseudoNr"
			$pseu=$row["pseudonummer"];
			$lfd=$row["laufendenummer"];
			$kennz.=$pseu."-".$lfd;
			$untertitel="Nebengebäude mit laufender Nummer (Lagebezeichnung mit Pseudonummer)";
			echo "\n<p class='lage'>ALKIS Lagebezeichnung Nebengebäude ".$kennz."&nbsp;</p>"; // Balken
			$osub="";
		break;
		case "o": // "Ohne HsNr"
			$unver=$row["unverschluesselt"]; // Gewanne
			// 2 Unterarten bzw. Zeilen-Typen in der Tabelle
			if ($lage == "") {
				$osub="g"; // Sub-Typ Gewanne
				$kennz=" - ".$unver;
				$untertitel="Gewanne (unverschl&uuml;sselte Lage)";
				echo "\n<p class='lage'>ALKIS Lagebezeichnung Ohne Hausnummer ".$kennz."&nbsp;</p>"; // Balken
			} else {
				$osub="s"; // Sub-Typ Strasse (ohne HsNr)
				$kennz.=$unver;
				$untertitel="Stra&szlig;e ohne Hausnummer";
				echo "\n<p class='lage'>ALKIS Lagebezeichnung Ohne Hausnummer ".$kennz."&nbsp;</p>"; // Balken
			}
		break;
	}
} else {
	echo "\n<p class='err'>Fehler! Kein Treffer fuer Lagebezeichnung mit gml_id='".$gmlid."'</p>";
	if ($debug > 2) {
		echo "\n<p class='err'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."<br>$1 = gml_id = '".$gmlid."'</p>";
	}
	echo "\n</body>\n</html>";
	exit;
}

echo "\n<h2><img src='ico/Lage_mit_Haus.png' width='16' height='16' alt='HAUS'> Lagebezeichnung</h2>\n"
."<p>Typ: ".$untertitel."</p>";

echo "\n<table class='outer'>\n<tr>\n\t<td>"; 	// Tab. Kennz.
	// ToDo: !! kleiner, wenn ltyp=0 und die Schluesselfelder leer sind
	echo "\n\t\t<table class='kennzla' title='Lage'>"
		."\n\t\t<tr>";
			if ($osub != "g") { // nicht bei Gewanne
				echo "\n\t\t\t<td class='head'>Land</td>"
				."\n\t\t\t<td class='head'>Reg.-Bez.</td>"
				."\n\t\t\t<td class='head'>Kreis</td>"
				."\n\t\t\t<td class='head'>Gemeinde</td>"
				."\n\t\t\t<td class='head'>Stra&szlig;e</td>";
			}
			switch ($ltyp) {
				case "m": // "Mit HsNr"
					echo "\n\t\t\t<td class='head'>Haus-Nr</td>";
				break;
				case "p": // "mit PseudoNr"
					echo "\n\t\t\t<td class='head'>Haus-Nr</td>"
					."\n\t\t\t<td class='head'>lfd.-Nr</td>";
				break;
				case "o": //"Ohne HsNr"
					if ($osub == "g") {
						echo "\n\t\t\t<td class='head'>unverschl&uuml;sselte Lage</td>";
					}
				break;
			}
		echo "\n\t\t</tr>\n\t\t<tr>";
			if ($osub != "g") { // nicht bei Gewanne

				echo "\n\t\t\t<td title='Bundesland'>";
				if ($showkey) {echo "<span class='key'>".$land."</span><br>";}
				echo $bnam."&nbsp;</td>";

				echo "\n\t\t\t<td title='Regierungsbezirk'>";
				if ($showkey) {echo "<span class='key'>".$regbez."</span><br>";}
				echo $rnam."&nbsp;</td>";

				echo "\n\t\t\t<td title='Kreis'>";
				if ($showkey and $osub != "g") {echo "<span class='key'>".$kreis."</span><br>";}
				echo $knam."&nbsp;</td>";

				echo "\n\t\t\t<td title='Gemeinde'>";
				if ($showkey and $osub != "g") {echo "<span class='key'>".$gem."</span><br>";}
				echo $gnam."&nbsp;</td>";

				echo "\n\t\t\t<td title='Stra&szlig;e'>";
				if ($showkey and $osub != "g") {echo "<span class='key'>".$lage."</span><br>";}
				if ($ltyp == "o") {
					echo "<span class='wichtig'>".$snam."</span>";
				} else {
					echo $snam;
				}	
				echo "&nbsp;</td>";
			}

			switch ($ltyp) {
				case "m":
					echo "\n\t\t\t<td title='Hausnummer und Zusatz'><span class='wichtig'>".$hsnr."</span></td>";
				break;
				case "p":
					echo "\n\t\t\t<td title='Pseudonummer - Nebengeb&auml;ude zu dieser Hausnummer'>".$pseu."</td>"
					."\n\t\t\t<td title='Laufende Nummer Nebengeb&auml;ude'><span class='wichtig'>".$lfd."</span></td>";
				break;
				case "o":
					if ($osub == "g") {
						echo "\n\t\t\t<td title='Gewanne'><span class='wichtig'>".$unver."</span></td>";
					}
				break;
			}
		echo "\n\t\t</tr>"
	."\n\t\t</table>";

	echo "\n\t</td>\n\t<td>";

	// Kopf Rechts: weitere Daten?
	if ($osub != "g") { // Link zu Strasse
		echo "\n\t\t<p class='nwlink noprint'>"
			."\n\t\t\t<a href='alkisstrasse.php?gkz=".$gkz."&amp;gmlid=".$strgml;
			if ($showkey) {echo "&amp;showkey=j";}
			echo "' title='Stra&szlig;e'>Stra&szlig;e <img src='ico/Strassen.png' width='16' height='16' alt=''></a>"
		."\n\t\t</p>";
	}

echo "\n\t</td>\n</tr>\n</table>";
// Ende Seitenkopf

// F L U R S T U E C K E
// ax_Flurstueck  >weistAuf>  ax_LagebezeichnungMitHausnummer
// ax_Flurstueck  >zeigtAuf>  ax_LagebezeichnungOhneHausnummer
// ++ auch Flächenverschneidung?
if ($ltyp <> "p") { // Pseudonummer linkt nur Gebäude
	echo "\n\n<a id='fs'></a>\n<h3><img src='ico/Flurstueck.png' width='16' height='16' alt=''> Flurst&uuml;cke</h3>"
	."\n<p>mit dieser Lagebezeichnung.</p>";
	switch ($ltyp) {
		case "m": $bezart="weistauf"; break;
		case "o": $bezart="zeigtauf"; break;
	}

	$sql="SELECT g.gemarkungsnummer, g.bezeichnung, f.gml_id, f.flurnummer, f.zaehler, f.nenner, f.amtlicheflaeche 
	FROM ax_flurstueck f LEFT JOIN ax_gemarkung g ON f.land=g.land AND f.gemarkungsnummer=g.gemarkungsnummer 
	WHERE $1 = ANY(f.".$bezart.") AND f.endet IS NULL AND g.endet IS NULL 
	ORDER BY f.gemarkungsnummer, f.flurnummer, f.zaehler, f.nenner;";

	$v = array($gmlid);
	$resf = pg_prepare("", $sql);
	$resf = pg_execute("", $v);
	if (!$resf) {
		echo "\n<p class='err'>Fehler bei Flurst&uuml;ck.</p>";
		if ($debug > 2) {echo "\n<p class='err'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."<br>$1 = gml_id = '".$gmlid."'</p>";}	
	}
	echo "\n<table class='fs'>"
	."\n<tr>"
		."\n\t<td class='heads'>Gemarkung<img src='ico/sort.png' width='10' height='10' alt='' title='Sortierung'></td>"
		."\n\t<td class='heads'>Flur<img src='ico/sort.png' width='10' height='10' alt='' title='Sortierung'></td>"
		."\n\t<td class='heads fsnr' title='Flurst&uuml;cksnummer (Z&auml;hler / Nenner)'><img src='ico/sort.png' width='10' height='10' alt='' title='Sortierung'>Flurst.</td>"
		."\n\t<td class='head fla'>Fl&auml;che</td>"
		."\n\t<td class='head nwlink noprint' title='Verlinkung zu anderen Nachweis-Arten und verbundenen Objekten'>weitere Auskunft</td>"
	."\n</tr>";
	$j=0;
	$zpaar=false;
	while($rowf = pg_fetch_array($resf)) {
		$flur=str_pad($rowf["flurnummer"], 3, "0", STR_PAD_LEFT);
		$fskenn=$rowf["zaehler"]; // Bruchnummer
		if ($rowf["nenner"] != "") {$fskenn.="/".$rowf["nenner"];}
		$flae=number_format($rowf["amtlicheflaeche"],0,",",".") . " m&#178;";

		if ($zpaar) {$trclass='paa';} else {$trclass='unp';}
		$zpaar=!$zpaar;

		echo "\n<tr class='".$trclass."'>"
			."\n\t<td>";
			if ($showkey) {echo "<span class='key'>".$rowf["gemarkungsnummer"]."</span> ";}
			echo $rowf["bezeichnung"]."</td>"
			."\n\t<td>".$flur."</td>"
			."\n\t<td class='fsnr'><span class='wichtig'>".$fskenn."</span></td>"
			."\n\t<td class='fla'>".$flae."</td>"
			."\n\t<td>\n\t\t<p class='nwlink noprint'>"
				."\n\t\t\t<a href='alkisfsnw.php?gkz=".$gkz."&amp;gmlid=".$rowf["gml_id"]."&amp;eig=n";
				if ($showkey) {echo "&amp;showkey=j";}
				echo "' title='Flurst&uuml;cksnachweis'>Flurst&uuml;ck <img src='ico/Flurstueck_Link.png' width='16' height='16' alt=''></a>"
			."\n\t\t</p>\n\t</td>"
		."\n</tr>";
		$j++;
	}
	echo "\n</table>";
	if ($j > 6) {echo "<p class='cnt'>".$j." Flurst&uuml;cke</p>";}
}

// L A G E
// andere Lage mit gleicher Hausnummer suchen
if ($ltyp <> "o") { // nicht bei Gewanne (Ohne HsNr)
	echo "\n\n<a id='lage'></a>\n<h3><img src='ico/Lage_mit_Haus.png' width='16' height='16' alt=''> Lage</h3>"
	."\n<p>Andere Lagebezeichnungen zur gleichen Hausnummer.</p>";
	$whereclaus="WHERE land= $1 AND regierungsbezirk= $2 AND kreis= $3 AND gemeinde= $4 AND lage= $5 ";

	$url=$_SERVER['PHP_SELF']."?gkz=".$gkz; // Basis
	if ($showkey) {$url.="&amp;showkey=j";}
	$url.="&amp;gmlid=";

	switch ($ltyp) {
		case "m": // aktuell: Hausnummer gefunden (Hauptgebäude)
			// dazu alle Nebengebäude suchen
			echo "\n<p>Nebengeb&auml;ude:&nbsp;";
			$sql ="SELECT l.gml_id, l.laufendenummer FROM ax_lagebezeichnungmitpseudonummer l "
			.$whereclaus."AND lage= $6 AND pseudonummer= $7 AND l.endet IS NULL ORDER BY laufendenummer;";

			$v = array($land,$regbez,$kreis,$gem,$lage,$lage,$hsnr);
			$res = pg_prepare("", $sql);
			$res = pg_execute("", $v);
			if (!$res) {
				echo "\n<p class='err'>Fehler bei Nebengeb&auml;ude.<br>".$sql."</p>";
				if ($debug > 2) {echo "\n<p class='err'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."</p>";}
			}
			$neb=0;
			while($row = pg_fetch_array($res)) {
				echo "\n\t<a href='".$url.$row["gml_id"]."&amp;ltyp=p'>lfd.-Nr ".$row["laufendenummer"]."</a>&nbsp;&nbsp;";
				$neb++;
			}
			if ($neb == 0) {echo "keine";}
			echo "</p>";
		break;

		case "p": // aktuell Nebengebäude: Haupt- und (andere) Nebengebäude suchen
			echo "\n<p>Hauptgeb&auml;ude: ";
			$sql ="SELECT l.gml_id FROM ax_lagebezeichnungmithausnummer l ".$whereclaus."AND hausnummer= $6 AND l.endet IS NULL ;";

			$v = array($land,$regbez,$kreis,$gem,$lage,$pseu);
			$res = pg_prepare("", $sql);
			$res = pg_execute("", $v);

			if (!$res) {echo "\n<p class='err'>Fehler bei Hauptgeb&auml;ude.<br>".$sql."</p>";}
			$hg=0;
			while($row = pg_fetch_array($res)) {
				echo "\n\t<a href='".$url.$row["gml_id"]."&amp;ltyp=m'>Haus-Nr ".$pseu."</a>&nbsp;&nbsp;";
				$hg++;
			}
			if ($hg == 0) {echo "&nbsp;Kein Hauptgeb&auml;ude gefunden.";}
			echo "</p>";

			echo "\n<p>Weitere Nebengeb&auml;ude:&nbsp;";
			$sql ="SELECT l.gml_id, l.laufendenummer FROM ax_lagebezeichnungmitpseudonummer l "
			.$whereclaus."AND pseudonummer= $6 AND laufendenummer <> $7 AND l.endet IS NULL ORDER BY laufendenummer;";
			$v=array($land,$regbez,$kreis,$gem,$lage,$pseu,$lfd);
			$res = pg_prepare("", $sql);
			$res = pg_execute("", $v);
			if (!$res) {
				echo "\n<p class='err'>Fehler bei Nebengeb&auml;ude.</p>";
				if ($debug > 2) {echo "\n<p class='err'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."</p>";}			
			}
			$neb=0;
			while($row = pg_fetch_array($res)) {
				echo "\n\t<a href='".$url.$row["gml_id"]."&amp;ltyp=p'>lfd.-Nr ".$row["laufendenummer"]."</a>&nbsp;&nbsp;";
				$neb++;
			}
			if ($neb == 0) {echo "keine";}
			echo "</p>";
		break;
	}
}

// G E B A E U D E
if ($ltyp <> "o") { // OhneHsNr linkt nur Flurst.
	echo "\n\n<a id='geb'></a>\n<h3><img src='ico/Haus.png' width='16' height='16' alt=''> Geb&auml;ude</h3>"
	."\n<p>mit dieser Lagebezeichnung.</p>";
	switch ($ltyp) {
		case "p": $bezart="g.hat"; break;
		case "m": $bezart="ANY(g.zeigtauf)"; break; // array
	}

	$sql ="SELECT g.gml_id, g.gebaeudefunktion, array_to_string(g.name, ',') AS name, g.bauweise, g.grundflaeche, g.zustand, round(st_area(g.wkb_geometry)::numeric,2) AS flaeche,
	h.v AS hv, h.d AS hd, u.v AS uv, u.d AS ud, z.v AS zv, z.d AS zd FROM ax_gebaeude g 
	LEFT JOIN alkis_wertearten h ON cast(g.bauweise AS character varying)=h.k AND h.element='ax_gebaeude' AND h.bezeichnung='bauweise'
	LEFT JOIN alkis_wertearten u ON cast(g.gebaeudefunktion AS character varying)=u.k AND u.element='ax_gebaeude' AND u.bezeichnung='gebaeudefunktion'
	LEFT JOIN alkis_wertearten z ON cast(g.zustand AS character varying)=z.k AND z.element='ax_gebaeude' AND z.bezeichnung='zustand'
	WHERE $1 = ".$bezart." AND g.endet IS NULL;";
	// Keine Sortierung (ORDER BY) notwendig weil i.d.R. nur ein (Haupt-)Gebäude diese Hausnummer hat.
	// Für weiter "alkis_wertearten" (Enstschlüsselungen) zum Gebäude dem Link "Haus" folgen.

	$v = array($gmlid);
	$res = pg_prepare("", $sql);
	$res = pg_execute("", $v);
	if (!$res) {
		echo "\n<p class='err'>Fehler bei Geb&auml;ude.</p>";
		if ($debug > 2) {echo "\n<p class='err'>SQL=<br>".htmlentities($sql, ENT_QUOTES, "UTF-8")."<br>$1 = gml_id = '".$gmlid."'</p>";}
	}
	echo "\n<table class='geb'>"
	."\n<tr>"
		."\n\t<td class='head' title='Name ist der Eigenname oder die Bezeichnung des Geb&auml;udes.'>Name</td>"
		."\n\t<td class='head fla' title='Fl&auml;che'>Fl&auml;che</td>"
		."\n\t<td class='head' title='Geb&auml;udefunktion ist die zum Zeitpunkt der Erhebung vorherrschend funktionale Bedeutung des Geb&auml;udes'>Funktion</td>"
		."\n\t<td class='head' title='Bauweise ist die Beschreibung der Art der Bauweise'>Bauweise</td>"
		."\n\t<td class='head' title='Zustand beschreibt die Beschaffenheit oder die Betriebsbereitschaft von Geb&auml;ude. Diese Attributart wird nur dann optional gef&uuml;hrt, wenn der Zustand des Geb&auml;udes vom nutzungsf&auml;higen Zustand abweicht.'>Zustand</td>"
		."\n\t<td class='head nwlink' title='Komplette Hausdaten'>Hausdaten</td>"
	."\n</tr>";
	$i=0;
	while($row = pg_fetch_array($res)) {
		$ggml=$row["gml_id"];
		$gfla=$row["flaeche"];
		echo "\n<tr>"
			."\n\t<td>".$row["name"]."</td>"
			."\n\t<td class='fla'>".$gfla." m&#178;</td>";

			echo "\n\t<td title='".htmlentities($row["ud"], ENT_QUOTES, "UTF-8")."'>";
			if ($showkey) {echo "<span class='key'>".htmlentities($row["gebaeudefunktion"], ENT_QUOTES, "UTF-8")."</span> ";}
			echo $row["uv"]."</td>";

			echo "\n\t<td title='".htmlentities($row["hd"], ENT_QUOTES, "UTF-8")."'>";
			if ($showkey) {echo "<span class='key'>".htmlentities($row["bauweise"], ENT_QUOTES, "UTF-8")."</span> ";}
			echo $row["hv"]."</td>";
				
			echo "\n\t<td title='".htmlentities($row["zd"] , ENT_QUOTES, "UTF-8")."'>";
			if ($showkey) {echo "<span class='key'>".htmlentities($row["zustand"], ENT_QUOTES, "UTF-8")."</span> ";}
			echo $row["zv"]."</td>";

			echo "\n\t<td class='nwlink noprint'>"
				."\n\t\t<a title='komplette Hausdaten' href='alkishaus.php?gkz=".$gkz."&amp;gmlid=".$ggml;
				if ($showkey) {echo "&amp;showkey=j";}
				echo "'>Haus <img src='ico/Haus.png' width='16' height='16' alt=''></a>"
			."\n\t</td>"
		."\n</tr>";
	}
	echo "\n</table>";
}
?>

<div class='buttonbereich noprint'>
	<hr>
	<a title="zur&uuml;ck" href='javascript:history.back()'><img src="ico/zurueck.png" width="16" height="16" alt="zur&uuml;ck"></a>&nbsp;
	<a title="Drucken" href='javascript:window.print()'><img src="ico/print.png" width="16" height="16" alt="Drucken"></a>&nbsp;
</div>

<?php footer($gmlid, $_SERVER['PHP_SELF']."?", "&amp;ltyp=".$ltyp); ?>

</body>
</html>
